==> tasks-v1.8.8.zip: tasks/messages/de/base.php <==
<?php

return [
    '1 Day before' => 'Einen Tag vorher',
    '1 Month before' => 'Einen Monat vorher',
    '1 Week before' => '1 Woche vorher',
    '2 Days before' => 'Zwei Tage vorher',
    '2 Weeks before' => '2 Wochen vorher',
    '3 Weeks before' => '3 Wochen vorher',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Zugewiesene Benutzer</strong> dürfen diese Aufgabe bearbeiten.',
    '<strong>Confirm</strong> task deletion' => 'Löschen der Aufgabe <strong>bestätigen</strong>',
    '<strong>Create</strong> task list' => 'Aufgabenliste <strong>erstellen</strong>',
    '<strong>Edit</strong> task' => 'Aufgabe <strong>bearbeiten</strong>',
    '<strong>Edit</strong> task list' => 'Aufgabenliste <strong>bearbeiten</strong>',
    '<strong>New</strong> Task' => '<strong>Neue</strong> Aufgabe',
    '<strong>Task</strong> Overview' => '<strong>Aufgaben</strong> Übersicht',
    '<strong>Tasks</strong>' => '<strong>Aufgaben</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>Tasks</strong> Modul Konfiguration',
    '<strong>Your</strong> tasks' => '<strong>Deine</strong> Aufgaben',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Ein Widget ist ein Element, das in die Seitenleiste eines Streams eingefügt wird. In diesem Fall bietet es den Nutzern einen kurzen Überblick über ihre Aufgaben.',
    'Accept Task' => 'Aufgabe akzeptieren',
    'Add Deadline to space calendar' => 'Fristende zum Space-Kalender hinzufügen',
    'Add checkpoint...' => 'Kontrollpunkt hinzufügen....',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Checklistenpunkte hinzufügen um Teilschritte hervorzuheben die für den Abschluss der Aufgabe nötig sind',
    'Add entry to main navigation' => 'Eintrag zur Hauptnavigation hinzufügen',
    'Add reminder' => 'Erinnerung hinzufügen',
    'Add responsible users' => 'Verantwortliche Benutzer hinzufügen',
    'Add schedule to the space calendar' => 'Zeitplanung zum Space-Kalender hinzufügen',
    'Add task' => 'Aufgabe erstellen',
    'Add to space calendar' => 'Zum Space-Kalender hinzufügen',
    'Additional options' => 'Weitere Optionen',
    'All Day' => 'Ganztägig',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Ermöglicht dem Benutzer das Erstellen neuer Aufgaben, der Benutzer kann nur eigene Aufgaben bearbeiten und löschen',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Erlaubt dem Benutzer die Erstellung, Löschung, Bearbeitung sowie Sortierung von Aufgaben und Listen',
    'Allows the user to process unassigned tasks' => 'Erlaubt dem Benutzer das Bearbeiten nicht zugewiesener Aufgaben',
    'Already requested' => 'Wurde bereits angefordert',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Jeder Benutzer mit der „Bearbeiten-nicht-zugewiesener-Aufgaben“-Erlaubnis kann an dieser Aufgabe arbeiten',
    'Anyone can work on this task!' => 'Jeder kann an dieser Aufgabe arbeiten!',
    'Assign myself' => 'Mich zuweisen',
    'Assign users' => 'Benutzer zuweisen',
    'Assigned' => 'Zugewiesen',
    'Assigned users' => 'Zugewiesene Benutzer',
    'Assignment' => 'Zuweisung',
    'Assignments:' => 'Zuweisungen:',
    'At least 1 Hour before' => 'Mindestens 1 Stunde vorher',
    'At least 2 Hours before' => 'Mindestens 2 Stunden vorher',
    'Attachments' => 'Anhänge',
    'Begin Task' => 'Aufgabe beginnen',
    'Checklist Items' => 'Checklisten-Einträge',
    'Checklist:' => 'Kontrollliste:',
    'Checkpoints' => 'Checkpunkte',
    'Choose if you want the module to appear in the main navigation.' => 'Wähle aus, ob das Modul in der Hauptnavigation erscheinen soll.',
    'Close' => 'Schliessen',
    'Color' => 'Farbe',
    'Completed' => 'Fertiggestellt',
    'Completed lists' => 'Abgeschlossene Listen',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Konfiguriere das Aufgabenmodul so, dass es deinen spezifischen Anforderungen und Bedürfnissen entspricht. Du kannst individuelle Einstellungen festlegen und zum Beispiel entscheiden, ob ein Widget angezeigt wird.',
    'Continue Review' => 'Überprüfung fortsetzen',
    'Create tasks' => 'Aufgaben erstellen',
    'Created by me' => 'Von mir erstellt',
    'Date' => 'Datum',
    'Deadline at' => 'Ende der Frist am',
    'Deadline: ' => 'Fristende:',
    'Delete' => 'Löschen',
    'Delete list' => 'Liste löschen',
    'Description' => 'Beschreibung',
    'Do not remind' => 'Nicht erinnern',
    'Do you really want to delete this task?' => 'Möchtest du diese Aufgabe wirklich löschen?',
    'Don\'t add to calendar' => 'Nicht zum Kalender hinzufügen',
    'Drag entry' => 'Eintrag ziehen',
    'Edit' => 'Bearbeiten',
    'Edit item (empty field will be removed)...' => 'Element bearbeiten (leeres Feld wird entfernt).....',
    'Edit list' => 'Liste bearbeiten',
    'End' => 'Ende',
    'End Date' => 'Enddatum',
    'End Time' => 'Endzeit',
    'End date' => 'Enddatum',
    'End time must be after start time!' => 'Die Endzeit muss nach der Startzeit liegen!',
    'Extend deadline request' => 'Fristverlängerung beantragen',
    'Filter' => 'Filter',
    'Filter by status' => 'Filtern nach Status',
    'Filter by title' => 'Filtern nach Titel',
    'Filter tasks' => 'Aufgaben filtern',
    'Finish Task' => 'Aufgabe fertigstellen',
    'General' => 'Allgemein',
    'General Settings' => 'Allgemeine Einstellungen',
    'Hide this list once all tasks are completed' => 'Blende diese Liste aus, sobald alle Aufgaben abgeschlossen sind',
    'I\'m assigned' => 'Mir zugewiesen',
    'I\'m responsible' => 'Ich bin verantwortlich',
    'If empty any user can complete the task.' => 'Falls leer, kann jeder diese Aufgabe erledigen',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Wenn kein zugewiesener Benutzer ausgewählt ist, kann jedes Gruppen-Mitglied mit der Berechtigung zum Verarbeiten nicht zugewiesener Aufgaben die Aufgaben verarbeiten.',
    'In Progress' => 'in Bearbeitung',
    'In Review' => 'wird überprüft',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Falls die Überprüfungsoption aktiviert ist, muss ein <strong>verantwortlicher Benutzer</strong> diese Aufgabe überprüfen und diese Aufgabe entweder vor dem Abschluss ablehnen oder bestätigen.',
    'Invalid task list selection.' => 'Ungültige Aufgabenlisten-Auswahl.',
    'Let Task Review' => 'Aufgabe überprüfen lassen',
    'Main Navigation' => 'Hauptnavigation',
    'Manage tasks' => 'Aufgaben verwalten',
    'Maximum number of entries in widget' => 'Maximale Anzahl Einträge im Widget',
    'Module Widget' => 'Modul Widget',
    'New list or search' => 'Neue Liste und Suche',
    'No Scheduling set for this Task' => 'Keine Terminierung für diese Aufgabe gesetzt',
    'No pending tasks found' => 'Keine offenen Aufgaben gefunden',
    'No results found for the given filter.' => 'Es wurden keine Ergebnisse für den angegebenen Filter gefunden.',
    'Open Task' => 'Zur Aufgabe',
    'Other Tasks' => 'andere Aufgaben',
    'Overdue' => 'Überfällig',
    'Overview' => 'Übersicht',
    'Parent Task' => 'Übergeordnete Aufgabe',
    'Pending' => 'Ausstehend',
    'Pending Review' => 'Ausstehende Überprüfung',
    'Process unassigned tasks' => 'Nicht zugewiesene Aufgaben bearbeiten',
    'Ready For Review' => 'Fertig zur Überprüfung',
    'Receive Notifications for Task Reminder.' => 'Benachrichtigungen für Aufgaben-Erinnerungen empfangen',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Benachrichtigungen zu Aufgaben erhalten (Friständerungen, Statusänderungen....) empfangen',
    'Reject Task' => 'Aufgabe zurückweisen',
    'Remind Mode' => 'Erinnerungsmodus',
    'Reminder' => 'Erinnerung',
    'Reminder sent' => 'Erinnerung verschickt',
    'Reminders' => 'Erinnerungen',
    'Request extension' => 'Verlängerung anfordern',
    'Request sent' => 'Anfrage gesendet',
    'Reset Task' => 'Aufgabe zurücksetzen',
    'Responsible' => 'Verantwortlich',
    'Responsible users' => 'Verantwortliche Benutzer',
    'Review by responsible user required' => 'Überprüfung durch verantwortlichen Benutzer notwendig',
    'Scheduling' => 'Zeitplanung',
    'Show widget in Spaces' => 'Zeige Widget in Spaces',
    'Show widget on Dashboard' => 'Zeige Widget auf dem Dashboard',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Zeige {count} weitere abgeschlossene {countTasks,plural,=1{Aufgabe} other{Aufgaben}}',
    'Sort Order' => 'Sortierung',
    'Sort order' => 'Sortierreihenfolge',
    'Spaces' => 'Spaces',
    'Start' => 'Beginn',
    'Start Date' => 'Startdatum',
    'Start Time' => 'Startzeit',
    'Start date' => 'Startdatum',
    'Starting at' => 'Startet um',
    'Status' => 'Status',
    'Task' => 'Aufgabe',
    'Task List' => 'Aufgabenliste',
    'Task Users have been notified' => 'Aufgaben-Benutzer wurden benachrichtigt',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Die Frist für die Aufgabe {task} im Space {spaceName} endet: {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Aufgabe {task} im Space {spaceName} beginnt am {dateTime}.',
    'Tasks' => 'Aufgaben',
    'Tasks: Reminder' => 'Aufgaben: Erinnerungen',
    'This task can only be processed by assigned and responsible users.' => 'Diese Aufgabe kann nur von zugewiesenen und verantwortlichen Benutzern bearbeitet werden.',
    'This task requires to be reviewed by a responsible' => 'Diese Aufgabe muss von einem Verantwortlichen überprüft werden.',
    'Time Zone' => 'Zeitzone',
    'Title' => 'Titel',
    'Title and Color' => 'Name und Farbe',
    'Title of your task list' => 'Name deiner Aufgabenliste',
    'Today' => 'Heute',
    'Unsorted' => 'unsortiert',
    'View Online' => 'Online ansehen',
    'You are assigned!' => 'Dir zugewiesen!',
    'You are responsible!' => 'Du bist verantwortlich!',
    'You have insufficient permissions to perform that operation!' => 'Du hast keine ausreichenden Berechtigungen, um diesen Vorgang auszuführen!',
    'Your Reminder for task {task}' => 'Deine Erinnerung für die Aufgabe {task}',
    'ending Review' => 'Beendigung der Überprüfung',
    'view all' => 'Zeige alle',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# Tag} other{# Tage}} bis Fristende',
    '{displayName} is assigned to this task' => '{displayName} ist dieser Aufgabe zugewiesen',
    '{displayName} is responsible for this task' => '{displayName} ist verantwortlich für diese Aufgabe',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} hat dich als verantwortliche Person für die Aufgabe {task} im Space {spaceName} zugeordnet.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} hat dich der Aufgabe {task} im Space {spaceName} zugewiesen.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} hat die Aufgabe {task} im Space {spaceName} fertiggestellt.',
    '{userName} completed task {task}.' => '{userName} hat die Aufgabe {task} fertiggestellt.',
    '{userName} finished task {task}.' => '{userName} hat die Aufgabe »{task}« abgeschlossen.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} hat die Frist für die Aufgabe {task} im Space {spaceName} verlängert.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} hat die Aufgabe {task} im Space {spaceName} wieder eröffnet.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} hat die Aufgabe {task} im Space {spaceName} als unfertig zurückgewiesen.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName}hat die Aufgabe {task} im Space {spaceName} als fertig markiert.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} bittet darum, die Frist für die Aufgabe {task} im Space{spaceName} zu verlängern.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} bittet dich die Aufgabe {task} im Space {spaceName} zu überprüfen.',
    '{userName} reset task {task}.' => '{userName} hat die Aufgabe {task} zurückgesetzt.',
    '{userName} reviewed task {task}.' => '{userName} hat die Aufgabe {task} überprüft.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} hat begonnen, an der Aufgabe {task} im Space {spaceName} zu arbeiten.',
    '{userName} works on task {task}.' => '{userName} arbeitet an der Aufgabe {task}.',
    'Task content ID' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/de/base.php <==
<?php

return [
    '1 Day before' => 'Einen Tag vorher',
    '1 Month before' => 'Einen Monat vorher',
    '1 Week before' => '1 Woche vorher',
    '2 Days before' => 'Zwei Tage vorher',
    '2 Weeks before' => '2 Wochen vorher',
    '3 Weeks before' => '3 Wochen vorher',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Zugewiesene Benutzer</strong> dürfen diese Aufgabe bearbeiten.',
    '<strong>Confirm</strong> task deletion' => 'Löschen der Aufgabe <strong>bestätigen</strong>',
    '<strong>Create</strong> task list' => 'Aufgabenliste <strong>erstellen</strong>',
    '<strong>Edit</strong> task' => 'Aufgabe <strong>bearbeiten</strong>',
    '<strong>Edit</strong> task list' => 'Aufgabenliste <strong>bearbeiten</strong>',
    '<strong>New</strong> Task' => '<strong>Neue</strong> Aufgabe',
    '<strong>Task</strong> Overview' => '<strong>Aufgaben</strong> Übersicht',
    '<strong>Tasks</strong>' => '<strong>Aufgaben</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>Tasks</strong> Modul Konfiguration',
    '<strong>Your</strong> tasks' => '<strong>Deine</strong> Aufgaben',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Ein Widget ist ein Element, das in die Seitenleiste eines Streams eingefügt wird. In diesem Fall bietet es den Nutzern einen kurzen Überblick über ihre Aufgaben.',
    'Accept Task' => 'Aufgabe akzeptieren',
    'Add Deadline to space calendar' => 'Fristende zum Space-Kalender hinzufügen',
    'Add checkpoint...' => 'Kontrollpunkt hinzufügen....',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Checklistenpunkte hinzufügen um Teilschritte hervorzuheben die für den Abschluss der Aufgabe nötig sind',
    'Add entry to main navigation' => 'Eintrag zur Hauptnavigation hinzufügen',
    'Add reminder' => 'Erinnerung hinzufügen',
    'Add responsible users' => 'Verantwortliche Benutzer hinzufügen',
    'Add schedule to the space calendar' => 'Zeitplanung zum Space-Kalender hinzufügen',
    'Add task' => 'Aufgabe erstellen',
    'Add to space calendar' => 'Zum Space-Kalender hinzufügen',
    'Additional options' => 'Weitere Optionen',
    'All Day' => 'Ganztägig',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Ermöglicht dem Benutzer das Erstellen neuer Aufgaben, der Benutzer kann nur eigene Aufgaben bearbeiten und löschen',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Erlaubt dem Benutzer die Erstellung, Löschung, Bearbeitung sowie Sortierung von Aufgaben und Listen',
    'Allows the user to process unassigned tasks' => 'Erlaubt dem Benutzer das Bearbeiten nicht zugewiesener Aufgaben',
    'Already requested' => 'Wurde bereits angefordert',
    'Assign myself' => 'Mich zuweisen',
    'Assign users' => 'Benutzer zuweisen',
    'Assigned users' => 'Zugewiesene Benutzer',
    'Assignment' => 'Zuweisung',
    'At least 1 Hour before' => 'Mindestens 1 Stunde vorher',
    'At least 2 Hours before' => 'Mindestens 2 Stunden vorher',
    'Attachments' => 'Anhänge',
    'Begin Task' => 'Aufgabe beginnen',
    'Checklist Items' => 'Checklisten-Einträge',
    'Checklist:' => 'Kontrollliste:',
    'Checkpoints' => 'Checkpunkte',
    'Choose if you want the module to appear in the main navigation.' => 'Wähle aus, ob das Modul in der Hauptnavigation erscheinen soll.',
    'Close' => 'Schliessen',
    'Color' => 'Farbe',
    'Completed' => 'Fertiggestellt',
    'Completed lists' => 'Abgeschlossene Listen',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Konfiguriere das Aufgabenmodul so, dass es deinen spezifischen Anforderungen und Bedürfnissen entspricht. Du kannst individuelle Einstellungen festlegen und zum Beispiel entscheiden, ob ein Widget angezeigt wird.',
    'Continue Review' => 'Überprüfung fortsetzen',
    'Create tasks' => 'Aufgaben erstellen',
    'Created by me' => 'Von mir erstellt',
    'Date' => 'Datum',
    'Deadline: ' => 'Fristende:',
    'Delete' => 'Löschen',
    'Delete list' => 'Liste löschen',
    'Description' => 'Beschreibung',
    'Do not remind' => 'Nicht erinnern',
    'Do you really want to delete this task?' => 'Möchtest du diese Aufgabe wirklich löschen?',
    'Don\'t add to calendar' => 'Nicht zum Kalender hinzufügen',
    'Edit' => 'Bearbeiten',
    'Edit item (empty field will be removed)...' => 'Element bearbeiten (leeres Feld wird entfernt).....',
    'Edit list' => 'Liste bearbeiten',
    'End' => 'Ende',
    'End Date' => 'Enddatum',
    'End Time' => 'Endzeit',
    'End date' => 'Enddatum',
    'End time must be after start time!' => 'Die Endzeit muss nach der Startzeit liegen!',
    'Extend deadline request' => 'Fristverlängerung beantragen',
    'Filter' => 'Filter',
    'Filter by status' => 'Filtern nach Status',
    'Filter by title' => 'Filtern nach Titel',
    'Filter tasks' => 'Aufgaben filtern',
    'Finish Task' => 'Aufgabe fertigstellen',
    'General' => 'Allgemein',
    'General Settings' => 'Allgemeine Einstellungen',
    'Hide this list once all tasks are completed' => 'Blende diese Liste aus, sobald alle Aufgaben abgeschlossen sind',
    'I\'m assigned' => 'Mir zugewiesen',
    'I\'m responsible' => 'Ich bin verantwortlich',
    'If empty any user can complete the task.' => 'Falls leer, kann jeder diese Aufgabe erledigen',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Wenn kein zugewiesener Benutzer ausgewählt ist, kann jedes Gruppen-Mitglied mit der Berechtigung zum Verarbeiten nicht zugewiesener Aufgaben die Aufgaben verarbeiten.',
    'In Progress' => 'in Bearbeitung',
    'In Review' => 'wird überprüft',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Falls die Überprüfungsoption aktiviert ist, muss ein <strong>verantwortlicher Benutzer</strong> diese Aufgabe überprüfen und diese Aufgabe entweder vor dem Abschluss ablehnen oder bestätigen.',
    'Invalid task list selection.' => 'Ungültige Aufgabenlisten-Auswahl.',
    'Let Task Review' => 'Aufgabe überprüfen lassen',
    'Main Navigation' => 'Hauptnavigation',
    'Manage tasks' => 'Aufgaben verwalten',
    'Maximum number of entries in widget' => 'Maximale Anzahl Einträge im Widget',
    'Module Widget' => 'Modul Widget',
    'New list or search' => 'Neue Liste und Suche',
    'No Scheduling set for this Task' => 'Keine Terminierung für diese Aufgabe gesetzt',
    'No pending tasks found' => 'Keine offenen Aufgaben gefunden',
    'No results found for the given filter.' => 'Es wurden keine Ergebnisse für den angegebenen Filter gefunden.',
    'Open Task' => 'Zur Aufgabe',
    'Other Tasks' => 'andere Aufgaben',
    'Overdue' => 'Überfällig',
    'Overview' => 'Übersicht',
    'Parent Task' => 'Übergeordnete Aufgabe',
    'Pending' => 'Ausstehend',
    'Pending Review' => 'Ausstehende Überprüfung',
    'Process unassigned tasks' => 'Nicht zugewiesene Aufgaben bearbeiten',
    'Ready For Review' => 'Fertig zur Überprüfung',
    'Receive Notifications for Task Reminder.' => 'Benachrichtigungen für Aufgaben-Erinnerungen empfangen',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Benachrichtigungen zu Aufgaben erhalten (Friständerungen, Statusänderungen....) empfangen',
    'Reject Task' => 'Aufgabe zurückweisen',
    'Remind Mode' => 'Erinnerungsmodus',
    'Reminder' => 'Erinnerung',
    'Reminder sent' => 'Erinnerung verschickt',
    'Reminders' => 'Erinnerungen',
    'Request extension' => 'Verlängerung anfordern',
    'Request sent' => 'Anfrage gesendet',
    'Reset Task' => 'Aufgabe zurücksetzen',
    'Responsible' => 'Verantwortlich',
    'Responsible users' => 'Verantwortliche Benutzer',
    'Review by responsible user required' => 'Überprüfung durch verantwortlichen Benutzer notwendig',
    'Scheduling' => 'Zeitplanung',
    'Show widget in Spaces' => 'Zeige Widget in Spaces',
    'Show widget on Dashboard' => 'Zeige Widget auf dem Dashboard',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Zeige {count} weitere abgeschlossene {countTasks,plural,=1{Aufgabe} other{Aufgaben}}',
    'Sort Order' => 'Sortierung',
    'Sort order' => 'Sortierreihenfolge',
    'Spaces' => 'Spaces',
    'Start' => 'Beginn',
    'Start Date' => 'Startdatum',
    'Start Time' => 'Startzeit',
    'Start date' => 'Startdatum',
    'Starting at' => 'Startet um',
    'Status' => 'Status',
    'Task' => 'Aufgabe',
    'Task List' => 'Aufgabenliste',
    'Task Users have been notified' => 'Aufgaben-Benutzer wurden benachrichtigt',
    'Task content ID' => 'Aufgaben Inhaltskennung',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Die Frist für die Aufgabe {task} im Space {spaceName} endet: {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Aufgabe {task} im Space {spaceName} beginnt am {dateTime}.',
    'Tasks' => 'Aufgaben',
    'Tasks: Reminder' => 'Aufgaben: Erinnerungen',
    'This task requires to be reviewed by a responsible' => 'Diese Aufgabe muss von einem Verantwortlichen überprüft werden.',
    'Time Zone' => 'Zeitzone',
    'Title' => 'Titel',
    'Title and Color' => 'Name und Farbe',
    'Title of your task list' => 'Name deiner Aufgabenliste',
    'Today' => 'Heute',
    'Unsorted' => 'unsortiert',
    'View Online' => 'Online ansehen',
    'You have insufficient permissions to perform that operation!' => 'Du hast keine ausreichenden Berechtigungen, um diesen Vorgang auszuführen!',
    'Your Reminder for task {task}' => 'Deine Erinnerung für die Aufgabe {task}',
    'view all' => 'Zeige alle',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# Tag} other{# Tage}} bis Fristende',
    '{displayName} is assigned to this task' => '{displayName} ist dieser Aufgabe zugewiesen',
    '{displayName} is responsible for this task' => '{displayName} ist verantwortlich für diese Aufgabe',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} hat dich als verantwortliche Person für die Aufgabe {task} im Space {spaceName} zugeordnet.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} hat dich der Aufgabe {task} im Space {spaceName} zugewiesen.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} hat die Aufgabe {task} im Space {spaceName} fertiggestellt.',
    '{userName} completed task {task}.' => '{userName} hat die Aufgabe {task} fertiggestellt.',
    '{userName} finished task {task}.' => '{userName} hat die Aufgabe »{task}« abgeschlossen.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} hat die Frist für die Aufgabe {task} im Space {spaceName} verlängert.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} hat die Aufgabe {task} im Space {spaceName} wieder eröffnet.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} hat die Aufgabe {task} im Space {spaceName} als unfertig zurückgewiesen.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName}hat die Aufgabe {task} im Space {spaceName} als fertig markiert.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} bittet darum, die Frist für die Aufgabe {task} im Space{spaceName} zu verlängern.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} bittet dich die Aufgabe {task} im Space {spaceName} zu überprüfen.',
    '{userName} reset task {task}.' => '{userName} hat die Aufgabe {task} zurückgesetzt.',
    '{userName} reviewed task {task}.' => '{userName} hat die Aufgabe {task} überprüft.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} hat begonnen, an der Aufgabe {task} im Space {spaceName} zu arbeiten.',
    '{userName} works on task {task}.' => '{userName} arbeitet an der Aufgabe {task}.',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    '{displayName} is task creator' => '',
];
